PEP: 392 Title: Python 3.2 Release Schedule Version: $Revision$
Last-Modified: $Date$ Author: Georg Brandl <georg@python.org> Status:
Final Type: Informational Content-Type: text/x-rst Created: 30-Dec-2009
Python-Version: 3.2

Abstract
========

This document describes the development and release schedule for the
Python 3.2 series. The schedule primarily concerns itself with PEP-sized
items.

.. Small features may be added up to and including the first beta
release. Bugs may be fixed until the final release, which is planned for
February 2011.

Release Manager and Crew
========================

-   3.2 Release Manager: Georg Brandl
-   Windows installers: Martin v. Loewis
-   Mac installers: Ronald Oussoren
-   Documentation: Georg Brandl

3.2 Lifespan
============

3.2 will receive bugfix updates approximately every 4-6 months for
approximately 18 months. After the release of 3.3.0 final (see PEP 398),
a final 3.2 bugfix update will be released. After that, security updates
(source only) will be released until 5 years after the release of 3.2
final, which was planned for February 2016.

As of 2016-02-20, Python 3.2.x reached end-of-life status. The final
source release was 3.2.6 in October 2014.

Release Schedule
================

3.2 schedule
------------

-   3.2 alpha 1: August 1, 2010
-   3.2 alpha 2: September 6, 2010
-   3.2 alpha 3: October 12, 2010
-   3.2 alpha 4: November 16, 2010
-   3.2 beta 1: December 6, 2010

(No new features beyond this point.)

-   3.2 beta 2: December 20, 2010
-   3.2 candidate 1: January 16, 2011
-   3.2 candidate 2: January 31, 2011
-   3.2 candidate 3: February 14, 2011
-   3.2 final: February 20, 2011

.. don't forget to update final date above as well

3.2.1 schedule
--------------

-   3.2.1 beta 1: May 8, 2011
-   3.2.1 candidate 1: May 17, 2011
-   3.2.1 candidate 2: July 3, 2011
-   3.2.1 final: July 11, 2011

3.2.2 schedule
--------------

-   3.2.2 candidate 1: August 14, 2011
-   3.2.2 final: September 4, 2011

3.2.3 schedule
--------------

-   3.2.3 candidate 1: February 25, 2012
-   3.2.3 candidate 2: March 18, 2012
-   3.2.3 final: April 11, 2012

3.2.4 schedule
--------------

-   3.2.4 candidate 1: March 23, 2013
-   3.2.4 final: April 6, 2013

3.2.5 schedule (regression fix release)
---------------------------------------

-   3.2.5 final: May 13, 2013

-- Only security releases after 3.2.5 --

3.2.6 schedule
--------------

-   3.2.6 candidate 1 (source-only release): October 4, 2014
-   3.2.6 final (source-only release): October 11, 2014

Features for 3.2
================

Note that PEP 3003 \[\#pep3003\]\_ is in effect: no changes to language
syntax and no additions to the builtins may be made.

No large-scale changes have been recorded yet.

References
==========

.. \[\#pep3003\] http://www.python.org/dev/peps/pep-3003/

Copyright
=========

This document has been placed in the public domain.

 .. Local Variables: mode: indented-text indent-tabs-mode: nil
sentence-end-double-space: t fill-column: 70 coding: utf-8 End:
